EnumKind

Trait EnumKind 

pub trait EnumKind: Copy {
    type Tag;

    // Required methods
    fn to_tag(self) -> Self::Tag;
    fn from_tag(tag: Self::Tag) -> Self;
}
An Inline identifying variants of an Enum.

Required Associated Types

type Tag

Underlying Inline. Typically EnumTag.

Required Methods

fn to_tag(self) -> Self::Tag

Get the underlying Inline.

fn from_tag(tag: Self::Tag) -> Self

Convert from an EnumTag assuming the value is within bounds, such that otherwise we have caught their violation during parsing of that tag.

Panics on out-of-bounds.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors