ByteOrd

Trait ByteOrd 

pub trait ByteOrd: ToOutput + PartialOrd {
    // Provided method
    fn bytes_cmp(&self, other: &Self) -> Ordering { ... }
}
Traits for which total order matches that of ToOutput::vec.

Provided Methods

fn bytes_cmp(&self, other: &Self) -> Ordering

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ByteOrd for ()

Source

fn bytes_cmp(&self, (): &Self) -> Ordering

Source

impl ByteOrd for Bytes

Available on crate feature bytes only.
Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for BytesMut

Available on crate feature bytes only.
Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for CStr

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for CString

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for Infallible

Source

fn bytes_cmp(&self, _: &Self) -> Ordering

Source

impl ByteOrd for Ordering

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for String

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for Ulid

Available on crate feature ulid only.
Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for bool

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for char

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for f32

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for f64

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for i8

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for i16

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for i32

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for i64

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for i128

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for str

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for u8

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for u16

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for u32

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for u64

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl ByteOrd for u128

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<'a, B: 'a + ToOwned + ByteOrd + ?Sized> ByteOrd for Cow<'a, B>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd + InlineOutput, G: ByteOrd + InlineOutput, H: ByteOrd + InlineOutput, I: ByteOrd + InlineOutput, J: ByteOrd + InlineOutput, K: ByteOrd + InlineOutput, L: ByteOrd> ByteOrd for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd + InlineOutput, G: ByteOrd + InlineOutput, H: ByteOrd + InlineOutput, I: ByteOrd + InlineOutput, J: ByteOrd + InlineOutput, K: ByteOrd> ByteOrd for (A, B, C, D, E, F, G, H, I, J, K)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd + InlineOutput, G: ByteOrd + InlineOutput, H: ByteOrd + InlineOutput, I: ByteOrd + InlineOutput, J: ByteOrd> ByteOrd for (A, B, C, D, E, F, G, H, I, J)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd + InlineOutput, G: ByteOrd + InlineOutput, H: ByteOrd + InlineOutput, I: ByteOrd> ByteOrd for (A, B, C, D, E, F, G, H, I)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd + InlineOutput, G: ByteOrd + InlineOutput, H: ByteOrd> ByteOrd for (A, B, C, D, E, F, G, H)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd + InlineOutput, G: ByteOrd> ByteOrd for (A, B, C, D, E, F, G)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd + InlineOutput, F: ByteOrd> ByteOrd for (A, B, C, D, E, F)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd + InlineOutput, E: ByteOrd> ByteOrd for (A, B, C, D, E)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd + InlineOutput, D: ByteOrd> ByteOrd for (A, B, C, D)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd + InlineOutput, C: ByteOrd> ByteOrd for (A, B, C)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<A: ByteOrd + InlineOutput, B: ByteOrd> ByteOrd for (A, B)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<K: ByteOrd + InlineOutput, V: ByteOrd + InlineOutput> ByteOrd for BTreeMap<K, V>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ?Sized + ByteOrd> ByteOrd for &T

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ?Sized + ByteOrd> ByteOrd for Arc<T>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ?Sized + ByteOrd> ByteOrd for Box<T>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ?Sized> ByteOrd for PhantomData<T>

Source

fn bytes_cmp(&self, _: &Self) -> Ordering

Source

impl<T: ByteOrd + InlineOutput, N: ArrayLength> ByteOrd for GenericArray<T, N>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ByteOrd + InlineOutput, const N: usize> ByteOrd for [T; N]

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ByteOrd + InlineOutput> ByteOrd for BTreeSet<T>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ByteOrd + InlineOutput> ByteOrd for Vec<T>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ByteOrd + InlineOutput> ByteOrd for VecDeque<T>

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ByteOrd + InlineOutput> ByteOrd for [T]

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Source

impl<T: ByteOrd> ByteOrd for (T,)

Source

fn bytes_cmp(&self, other: &Self) -> Ordering

Implementors