Fetch

Trait Fetch 

pub trait Fetch:
    Send
    + Sync
    + FetchBytes {
    type T;

    // Required method
    fn fetch(&self) -> FailFuture<'_, Self::T>;

    // Provided methods
    fn try_fetch_local(&self) -> Result<Option<Self::T>> { ... }
    fn fetch_local(&self) -> Option<Self::T> { ... }
    fn get(&self) -> Option<&Self::T> { ... }
    fn get_mut(&mut self) -> Option<&mut Self::T> { ... }
    fn get_mut_finalize(&mut self) { ... }
    fn try_unwrap(self: Arc<Self>) -> Option<Self::T> { ... }
    fn into_dyn_fetch<'a>(self) -> Arc<dyn Fetch<T = Self::T> + 'a> 
       where Self: 'a + Sized { ... }
}
Application-facing traversal.

Required Associated Types

type T

Fetched object.

Required Methods

fn fetch(&self) -> FailFuture<'_, Self::T>

Main traversal method.

Provided Methods

fn try_fetch_local(&self) -> Result<Option<Self::T>>

Attempt to fetch the object locally.

Generally this is either Fetch::get+Clone::clone or FetchBytes::fetch_bytes_local+Parse::parse.

fn fetch_local(&self) -> Option<Self::T>

Fetch locally if possible. Typically this is just Fetch::get+Clone::clone.

fn get(&self) -> Option<&Self::T>

Get a reference to a locally stored object.

fn get_mut(&mut self) -> Option<&mut Self::T>

Get a mutable reference to a locally stored object.

Fetch::get_mut_finalize must be called to restore the state even if no mutations were made.

fn get_mut_finalize(&mut self)

Restore the inner state after mutations completed (for example, [Hash] of what’s stored).

fn try_unwrap(self: Arc<Self>) -> Option<Self::T>

Attempt unwrapping the object stored locally.

fn into_dyn_fetch<'a>(self) -> Arc<dyn Fetch<T = Self::T> + 'a>
where Self: 'a + Sized,

Convenience method to force a conversion to a trait object.