InlineOutput

Trait InlineOutput 

pub trait InlineOutput: ToOutput {
    // Provided method
    fn slice_to_output(slice: &[Self], output: &mut impl Output)
       where Self: Sized { ... }
}
Marker trait indicating that ToOutput result cannot be extended (no value, when represented as a Vec<u8>, may be a prefix of another value).

Provided Methods

fn slice_to_output(slice: &[Self], output: &mut impl Output)
where Self: Sized,

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl InlineOutput for Ordering

Source

impl InlineOutput for Infallible

Source

impl InlineOutput for bool

Source

impl InlineOutput for char

Source

impl InlineOutput for f32

Source

impl InlineOutput for f64

Source

impl InlineOutput for i8

Source

impl InlineOutput for i16

Source

impl InlineOutput for i32

Source

impl InlineOutput for i64

Source

impl InlineOutput for i128

Source

impl InlineOutput for u8

Source

fn slice_to_output(slice: &[Self], output: &mut impl Output)
where Self: Sized,

Source

impl InlineOutput for u16

Source

impl InlineOutput for u32

Source

impl InlineOutput for u64

Source

impl InlineOutput for u128

Source

impl InlineOutput for ()

Source

impl InlineOutput for CString

Source

impl InlineOutput for CStr

Source

impl InlineOutput for Ulid

Available on crate feature ulid only.
Source

impl<'a, B: 'a + ToOwned + InlineOutput + ?Sized> InlineOutput for Cow<'a, B>

Source

impl<A, O: BitOrder> InlineOutput for BitArray<A, O>

Available on crate feature bitvec only.
Source

impl<A: InlineOutput, B: InlineOutput> InlineOutput for (A, B)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput> InlineOutput for (A, B, C)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput> InlineOutput for (A, B, C, D)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput> InlineOutput for (A, B, C, D, E)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput> InlineOutput for (A, B, C, D, E, F)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput> InlineOutput for (A, B, C, D, E, F, G)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput, L: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<T> InlineOutput for dyn Send + Sync + ExtraFor<T>

Source

impl<T: InlineOutput + TaggedOption> InlineOutput for Option<T>

Source

impl<T: InlineOutput> InlineOutput for (T,)

Source

impl<T: InlineOutput, N: ArrayLength> InlineOutput for GenericArray<T, N>

Source

impl<T: InlineOutput, const N: usize> InlineOutput for [T; N]

Source

impl<T: ?Sized + InlineOutput> InlineOutput for &T

Source

impl<T: ?Sized + InlineOutput> InlineOutput for Box<T>

Source

impl<T: ?Sized + InlineOutput> InlineOutput for Arc<T>

Source

impl<T: ?Sized> InlineOutput for PhantomData<T>

Implementors

Source

impl InlineOutput for LpBytes

Source

impl InlineOutput for LpString

Source

impl InlineOutput for Be<f32>

Source

impl InlineOutput for Be<f64>

Source

impl InlineOutput for Be<i8>

Source

impl InlineOutput for Be<i16>

Source

impl InlineOutput for Be<i32>

Source

impl InlineOutput for Be<i64>

Source

impl InlineOutput for Be<i128>

Source

impl InlineOutput for Be<u8>

Source

impl InlineOutput for Be<u16>

Source

impl InlineOutput for Be<u32>

Source

impl InlineOutput for Be<u64>

Source

impl InlineOutput for Be<u128>

Source

impl InlineOutput for Le<f32>

Source

impl InlineOutput for Le<f64>

Source

impl InlineOutput for Le<i8>

Source

impl InlineOutput for Le<i16>

Source

impl InlineOutput for Le<i32>

Source

impl InlineOutput for Le<i64>

Source

impl InlineOutput for Le<i128>

Source

impl InlineOutput for Le<u8>

Source

impl InlineOutput for Le<u16>

Source

impl InlineOutput for Le<u32>

Source

impl InlineOutput for Le<u64>

Source

impl InlineOutput for Le<u128>

Source

impl InlineOutput for Address

Source

impl InlineOutput for Hash
where [u8; 32]: InlineOutput,

Source

impl InlineOutput for OptionalHash
where [u8; 32]: InlineOutput,

Source

impl InlineOutput for Extra0

Source

impl InlineOutput for Extra1

Source

impl InlineOutput for Swap

Source

impl InlineOutput for U63

Source

impl InlineOutput for dyn Resolve

Source

impl InlineOutput for dyn Singular

Source

impl<Extra> InlineOutput for InlineExtra<Extra>
where Extra: InlineOutput,

Source

impl<K> InlineOutput for PartialByteTag<K>

Source

impl<T, M> InlineOutput for MappedExtra<T, M>

Source

impl<T, const MAX: usize> InlineOutput for EnumTag<T, MAX>
where T: InlineOutput,

Source

impl<T: ToOutput> InlineOutput for Hashed<T>

Source

impl<T: ToOutput> InlineOutput for Lp<T>

Source

impl<T: ToOutput> InlineOutput for ParseExtra<T>

Source

impl<T: ToOutput> InlineOutput for Zt<T>

Source

impl<T: ?Sized> InlineOutput for ObjectMarker<T>
where PhantomData<fn() -> T>: InlineOutput,