Resolve

Trait Resolve 

pub trait Resolve:
    Send
    + Sync
    + AsAny {
    // Required methods
    fn resolve<'a>(
        &'a self,
        address: Address,
        this: &'a Arc<dyn Resolve>,
    ) -> FailFuture<'a, ByteNode>;
    fn resolve_data(&self, address: Address) -> FailFuture<'_, Vec<u8>>;

    // Provided methods
    fn try_resolve_local(
        &self,
        address: Address,
        this: &Arc<dyn Resolve>,
    ) -> Result<Option<ByteNode>> { ... }
    fn topology_hash(&self) -> Option<Hash> { ... }
    fn into_topovec(self: Arc<Self>) -> Option<TopoVec> { ... }
}
Something that can resolve Addresses to ByteNodes.

Required Methods

fn resolve<'a>( &'a self, address: Address, this: &'a Arc<dyn Resolve>, ) -> FailFuture<'a, ByteNode>

Resolve the address. For an Object, this is what gets used as PointInput.

this points to same thing as self. Provided for ease of cloning [Hash]-based Resolves.

fn resolve_data(&self, address: Address) -> FailFuture<'_, Vec<u8>>

Resolve data only (without a nested Resolve).

Provided Methods

fn try_resolve_local( &self, address: Address, this: &Arc<dyn Resolve>, ) -> Result<Option<ByteNode>>

Attempt resolving assuming something is local. Returns None when it’s not known to be local.

fn topology_hash(&self) -> Option<Hash>

Topology hash of the underyling sequence if this resolver is index-based.

fn into_topovec(self: Arc<Self>) -> Option<TopoVec>

Attempt unwrapping a TopoVec. Generally shouldn’t be implemented.