pub struct TupleOfArrays<A, B>(/* private fields */);Trait Implementations
Sourceimpl<A: Clone, B: Clone> Clone for TupleOfArrays<A, B>
impl<A: Clone, B: Clone> Clone for TupleOfArrays<A, B>
Sourcefn clone(&self) -> TupleOfArrays<A, B>
fn clone(&self) -> TupleOfArrays<A, B>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<A: Copy, B: Copy> Copy for TupleOfArrays<A, B>
Sourceimpl<A: Default, B: Default> Default for TupleOfArrays<A, B>
impl<A: Default, B: Default> Default for TupleOfArrays<A, B>
Sourcefn default() -> TupleOfArrays<A, B>
fn default() -> TupleOfArrays<A, B>
Returns the “default value” for a type. Read more
impl<A: Eq, B: Eq> Eq for TupleOfArrays<A, B>
Sourceimpl<A: Extend<L>, B: Extend<R>, L, R> Extend<(L, R)> for TupleOfArrays<A, B>
impl<A: Extend<L>, B: Extend<R>, L, R> Extend<(L, R)> for TupleOfArrays<A, B>
Sourcefn extend<T: IntoIterator<Item = (L, R)>>(&mut self, iter: T)
fn extend<T: IntoIterator<Item = (L, R)>>(&mut self, iter: T)
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl<A: FromIterator<L>, B: FromIterator<R>, L, R> FromIterator<(L, R)> for TupleOfArrays<A, B>
impl<A: FromIterator<L>, B: FromIterator<R>, L, R> FromIterator<(L, R)> for TupleOfArrays<A, B>
Sourceimpl<A: IntoIterator, B: IntoIterator> IntoIterator for TupleOfArrays<A, B>
impl<A: IntoIterator, B: IntoIterator> IntoIterator for TupleOfArrays<A, B>
Sourcetype Item = (<A as IntoIterator>::Item, <B as IntoIterator>::Item)
type Item = (<A as IntoIterator>::Item, <B as IntoIterator>::Item)
The type of the elements being iterated over.
Sourcetype IntoIter = Zip<<A as IntoIterator>::IntoIter, <B as IntoIterator>::IntoIter>
type IntoIter = Zip<<A as IntoIterator>::IntoIter, <B as IntoIterator>::IntoIter>
Which kind of iterator are we turning this into?
Sourceimpl<'a, A, B> IntoIterator for &'a TupleOfArrays<A, B>
impl<'a, A, B> IntoIterator for &'a TupleOfArrays<A, B>
Sourcetype Item = (<&'a A as IntoIterator>::Item, <&'a B as IntoIterator>::Item)
type Item = (<&'a A as IntoIterator>::Item, <&'a B as IntoIterator>::Item)
The type of the elements being iterated over.
Sourcetype IntoIter = Zip<<&'a A as IntoIterator>::IntoIter, <&'a B as IntoIterator>::IntoIter>
type IntoIter = Zip<<&'a A as IntoIterator>::IntoIter, <&'a B as IntoIterator>::IntoIter>
Which kind of iterator are we turning this into?
Sourceimpl<'a, A, B> IntoIterator for &'a mut TupleOfArrays<A, B>
impl<'a, A, B> IntoIterator for &'a mut TupleOfArrays<A, B>
Sourcetype Item = (<&'a mut A as IntoIterator>::Item, <&'a mut B as IntoIterator>::Item)
type Item = (<&'a mut A as IntoIterator>::Item, <&'a mut B as IntoIterator>::Item)
The type of the elements being iterated over.
Sourcetype IntoIter = Zip<<&'a mut A as IntoIterator>::IntoIter, <&'a mut B as IntoIterator>::IntoIter>
type IntoIter = Zip<<&'a mut A as IntoIterator>::IntoIter, <&'a mut B as IntoIterator>::IntoIter>
Which kind of iterator are we turning this into?
Sourceimpl<A, B> ListHashes for TupleOfArrays<A, B>where
A: ListHashes,
B: ListHashes,
impl<A, B> ListHashes for TupleOfArrays<A, B>where
A: ListHashes,
B: ListHashes,
fn list_hashes(&self, visitor: &mut impl FnMut(Hash))
fn topology_hash(&self) -> Hash
fn point_count(&self) -> usize
Sourceimpl<A: Ord, B: Ord> Ord for TupleOfArrays<A, B>
impl<A: Ord, B: Ord> Ord for TupleOfArrays<A, B>
Sourcefn cmp(&self, other: &TupleOfArrays<A, B>) -> Ordering
fn cmp(&self, other: &TupleOfArrays<A, B>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<A: Parse<I> + PlainCollection<Item = Ae>, B: Parse<I> + PlainCollection<Item = Be>, I: ParseInput, Ae: Size, Be: Size> Parse<I> for TupleOfArrays<A, B>
impl<A: Parse<I> + PlainCollection<Item = Ae>, B: Parse<I> + PlainCollection<Item = Be>, I: ParseInput, Ae: Size, Be: Size> Parse<I> for TupleOfArrays<A, B>
Sourceimpl<A: PartialEq, B: PartialEq> PartialEq for TupleOfArrays<A, B>
impl<A: PartialEq, B: PartialEq> PartialEq for TupleOfArrays<A, B>
Sourcefn eq(&self, other: &TupleOfArrays<A, B>) -> bool
fn eq(&self, other: &TupleOfArrays<A, B>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<A: PartialOrd, B: PartialOrd> PartialOrd for TupleOfArrays<A, B>
impl<A: PartialOrd, B: PartialOrd> PartialOrd for TupleOfArrays<A, B>
impl<A: PlainCollection, B: PlainCollection> PlainCollection for TupleOfArrays<A, B>
Sourceimpl<A, B> Size for TupleOfArrays<A, B>
impl<A, B> Size for TupleOfArrays<A, B>
impl<A: PartialEq, B: PartialEq> StructuralPartialEq for TupleOfArrays<A, B>
Sourceimpl<A, B> Tagged for TupleOfArrays<A, B>
impl<A, B> Tagged for TupleOfArrays<A, B>
Sourceimpl<A, B> Topological for TupleOfArrays<A, B>where
A: Topological,
B: Topological,
impl<A, B> Topological for TupleOfArrays<A, B>where
A: Topological,
B: Topological,