pub type TopoVec = Vec<Arc<dyn Singular>>;Aliased Type
pub struct TopoVec { /* private fields */ }Trait Implementations
Sourceimpl PointVisitor for TopoVec
impl PointVisitor for TopoVec
Sourcefn visit(
&mut self,
point: &(impl 'static + SingularFetch<T: Traversible> + Clone),
)
fn visit( &mut self, point: &(impl 'static + SingularFetch<T: Traversible> + Clone), )
Visit one
SingularFetch of an object. Points are provided in a fixed known order (mostly
means order of parsing).Sourceimpl Resolve for TopoVec
impl Resolve for TopoVec
Sourcefn resolve<'a>(
&'a self,
address: Address,
_: &'a Arc<dyn Resolve>,
) -> FailFuture<'a, ByteNode>
fn resolve<'a>( &'a self, address: Address, _: &'a Arc<dyn Resolve>, ) -> FailFuture<'a, ByteNode>
Sourcefn resolve_data(&self, address: Address) -> FailFuture<'_, Vec<u8>>
fn resolve_data(&self, address: Address) -> FailFuture<'_, Vec<u8>>
Resolve data only (without a nested
Resolve).Sourcefn try_resolve_local(
&self,
address: Address,
_: &Arc<dyn Resolve>,
) -> Result<Option<ByteNode>>
fn try_resolve_local( &self, address: Address, _: &Arc<dyn Resolve>, ) -> Result<Option<ByteNode>>
Attempt resolving assuming something is local. Returns
None when it’s not known to be
local.Sourcefn topology_hash(&self) -> Option<Hash>
fn topology_hash(&self) -> Option<Hash>
Topology hash of the underyling sequence if this resolver is index-based.