Address

Struct Address 

pub struct Address {
    pub index: usize,
    pub hash: Hash,
}
Address within a PointInput.

This was introduced:

  • to avoid using a [Hash]-only map
  • to differentiate between separate [Hash]es within a context

Fields

index: usize

Monotonically incremented index. This is not present at all in the actual format.

hash: Hash

Only this part is part of the parsed/generated input.

Implementations

Source

impl Address

pub fn from_hash(hash: Hash) -> Self

Construct an address which is invalid within parsing context, but can be used in map-based Resolves.