pub struct Address {
pub index: usize,
pub hash: Hash,
}Expand description
Address within a PointInput.
This was introduced:
- to avoid using a [
Hash]-only map - to differentiate between separate [
Hash]es within a context
While Address implements a bunch of traits from the object hierarchy, it’s not a member of
it: Addresses are supposed to be used with Resolves. Thus, it notably doesn’t implement
Topological.
Fields
index: usizeMonotonically incremented index. This is not present at all in the actual format.
hash: HashOnly this part is part of the parsed/generated input.
Implementations