InlineOutput

Trait InlineOutput 

pub trait InlineOutput: ToOutput {
    // Provided method
    fn slice_to_output(slice: &[Self], output: &mut dyn Output)
       where Self: Sized { ... }
}
Marker trait indicating that ToOutput result cannot be extended.

Provided Methods

fn slice_to_output(slice: &[Self], output: &mut dyn Output)
where Self: Sized,

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl InlineOutput for Infallible

Source

impl InlineOutput for bool

Source

impl InlineOutput for char

Source

impl InlineOutput for i8

Source

impl InlineOutput for u8

Source

fn slice_to_output(slice: &[Self], output: &mut dyn Output)
where Self: Sized,

Source

impl InlineOutput for ()

Source

impl InlineOutput for CString

Source

impl InlineOutput for CStr

Source

impl InlineOutput for Ulid

Available on crate feature ulid only.
Source

impl<'a, B: 'a + ToOwned + InlineOutput + ?Sized> InlineOutput for Cow<'a, B>

Source

impl<A, O: BitOrder> InlineOutput for BitArray<A, O>

Available on crate feature bitvec only.
Source

impl<A: InlineOutput, B: InlineOutput> InlineOutput for (A, B)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput> InlineOutput for (A, B, C)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput> InlineOutput for (A, B, C, D)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput> InlineOutput for (A, B, C, D, E)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput> InlineOutput for (A, B, C, D, E, F)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput> InlineOutput for (A, B, C, D, E, F, G)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput, L: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<T: InlineOutput + TaggedOption> InlineOutput for Option<T>

Source

impl<T: InlineOutput> InlineOutput for &T

Source

impl<T: InlineOutput> InlineOutput for (T,)

Source

impl<T: InlineOutput, N: ArrayLength> InlineOutput for GenericArray<T, N>

Source

impl<T: InlineOutput, const N: usize> InlineOutput for [T; N]

Source

impl<T: ?Sized + InlineOutput> InlineOutput for Box<T>

Source

impl<T: ?Sized + InlineOutput> InlineOutput for Arc<T>

Source

impl<T: ?Sized> InlineOutput for PhantomData<T>

Implementors