pub trait InlineOutput: ToOutput {
// Provided method
fn slice_to_output(slice: &[Self], output: &mut impl Output)
where Self: Sized { ... }
}Expand description
Marker trait indicating that ToOutput result cannot be extended (no value, when represented
as a Vec<u8>, may be a prefix of another value).
Provided Methods
fn slice_to_output(slice: &[Self], output: &mut impl Output)where
Self: Sized,
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl InlineOutput for ()
impl InlineOutput for CStr
impl InlineOutput for CString
impl InlineOutput for Infallible
impl InlineOutput for Ordering
impl InlineOutput for Ulid
Available on crate feature
ulid only.impl InlineOutput for bool
impl InlineOutput for char
impl InlineOutput for f32
impl InlineOutput for f64
impl InlineOutput for i8
impl InlineOutput for i16
impl InlineOutput for i32
impl InlineOutput for i64
impl InlineOutput for i128
Sourceimpl InlineOutput for u8
impl InlineOutput for u8
fn slice_to_output(slice: &[Self], output: &mut impl Output)where
Self: Sized,
impl InlineOutput for u16
impl InlineOutput for u32
impl InlineOutput for u64
impl InlineOutput for u128
impl<'a, B: 'a + ToOwned + InlineOutput + ?Sized> InlineOutput for Cow<'a, B>
impl<A, O: BitOrder> InlineOutput for BitArray<A, O>
Available on crate feature
bitvec only.impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput, L: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J, K, L)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J, K)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I, J)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H, I)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput> InlineOutput for (A, B, C, D, E, F, G, H)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput> InlineOutput for (A, B, C, D, E, F, G)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput> InlineOutput for (A, B, C, D, E, F)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput> InlineOutput for (A, B, C, D, E)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput> InlineOutput for (A, B, C, D)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput> InlineOutput for (A, B, C)
impl<A: InlineOutput, B: InlineOutput> InlineOutput for (A, B)
impl<T: ?Sized + InlineOutput> InlineOutput for &T
impl<T: ?Sized + InlineOutput> InlineOutput for Arc<T>
impl<T: ?Sized + InlineOutput> InlineOutput for Box<T>
impl<T: ?Sized> InlineOutput for PhantomData<T>
impl<T: InlineOutput + TaggedOption> InlineOutput for Option<T>
impl<T: InlineOutput, N: ArrayLength> InlineOutput for GenericArray<T, N>
impl<T: InlineOutput, const N: usize> InlineOutput for [T; N]
impl<T: InlineOutput> InlineOutput for (T,)
impl<T> InlineOutput for dyn Send + Sync + ExtraFor<T>
impl<const S: usize> InlineOutput for CidGeneric<S>
Available on crate feature
cid only.We don’t run into prefix issues because S is const.