pub trait Parse<I: ParseInput>: Sized {
// Required method
fn parse(input: I) -> Result<Self>;
}Expand description
This can be parsed by consuming the whole rest of the input.
Nothing can be parsed after this. It’s implementation’s responsibility to ensure there are no leftover bytes.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<A, O: BitOrder, __I: ParseInput> Parse<__I> for BitArray<A, O>
Available on crate feature bitvec only.
impl<A, O: BitOrder, __I: ParseInput> Parse<__I> for BitArray<A, O>
Available on crate feature
bitvec only.Sourceimpl<I: ParseInput> Parse<I> for Ulid
Available on crate feature ulid only.
impl<I: ParseInput> Parse<I> for Ulid
Available on crate feature
ulid only.