pub trait ToOutput {
// Required method
fn to_output(&self, output: &mut impl Output);
// Provided methods
fn data_hash(&self) -> Hash { ... }
fn mangle_hash(&self) -> Hash { ... }
fn output<T: Output + Default>(&self) -> T { ... }
fn vec(&self) -> Vec<u8> ⓘ { ... }
}Expand description
Values of this type can be uniquely represented as a Vec<u8>.
Required Methods
Provided Methods
fn data_hash(&self) -> Hash
fn mangle_hash(&self) -> Hash
fn output<T: Output + Default>(&self) -> T
fn vec(&self) -> Vec<u8> ⓘ
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput, L: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I, J, K, L)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: InlineOutput, L: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I, J, K, L)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I, J, K)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: InlineOutput, K: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I, J, K)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I, J)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: InlineOutput, J: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I, J)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: InlineOutput, I: ToOutput> ToOutput for (A, B, C, D, E, F, G, H, I)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: ToOutput> ToOutput for (A, B, C, D, E, F, G, H)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: InlineOutput, H: ToOutput> ToOutput for (A, B, C, D, E, F, G, H)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: ToOutput> ToOutput for (A, B, C, D, E, F, G)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: InlineOutput, G: ToOutput> ToOutput for (A, B, C, D, E, F, G)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: ToOutput> ToOutput for (A, B, C, D, E, F)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: InlineOutput, F: ToOutput> ToOutput for (A, B, C, D, E, F)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: ToOutput> ToOutput for (A, B, C, D, E)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: InlineOutput, E: ToOutput> ToOutput for (A, B, C, D, E)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: ToOutput> ToOutput for (A, B, C, D)
impl<A: InlineOutput, B: InlineOutput, C: InlineOutput, D: ToOutput> ToOutput for (A, B, C, D)
Sourceimpl<A: InlineOutput, B: InlineOutput, C: ToOutput> ToOutput for (A, B, C)
impl<A: InlineOutput, B: InlineOutput, C: ToOutput> ToOutput for (A, B, C)
Sourceimpl<K: InlineOutput, V: InlineOutput> ToOutput for BTreeMap<K, V>
impl<K: InlineOutput, V: InlineOutput> ToOutput for BTreeMap<K, V>
Sourceimpl<K: InlineOutput, V: InlineOutput> ToOutput for IndexMap<K, V>
Available on crate feature indexmap only.
impl<K: InlineOutput, V: InlineOutput> ToOutput for IndexMap<K, V>
Available on crate feature
indexmap only.Sourceimpl<T: InlineOutput, N: ArrayLength> ToOutput for GenericArray<T, N>
impl<T: InlineOutput, N: ArrayLength> ToOutput for GenericArray<T, N>
Sourceimpl<T: InlineOutput> ToOutput for BTreeSet<T>
impl<T: InlineOutput> ToOutput for BTreeSet<T>
Sourceimpl<T: InlineOutput> ToOutput for IndexSet<T>
Available on crate feature indexmap only.
impl<T: InlineOutput> ToOutput for IndexSet<T>
Available on crate feature
indexmap only.Sourceimpl<T: InlineOutput> ToOutput for Vec<T>
impl<T: InlineOutput> ToOutput for Vec<T>
Sourceimpl<T: InlineOutput> ToOutput for VecDeque<T>
impl<T: InlineOutput> ToOutput for VecDeque<T>
Sourceimpl<T> ToOutput for Option<T>where
T: OptionOutput,
impl<T> ToOutput for Option<T>where
T: OptionOutput,
Sourceimpl<const S: usize> ToOutput for CidGeneric<S>
Available on crate feature cid only.
impl<const S: usize> ToOutput for CidGeneric<S>
Available on crate feature
cid only.